@@ -4,7 +4,7 @@
 
 import _core
 
-def _swig_setattr(self,class_type,name,value):
+def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
     if (name == "this"):
         if isinstance(value, class_type):
             self.__dict__[name] = value.this
@@ -13,7 +13,13 @@ def _swig_setattr(self,class_type,name,value):
             return
     method = class_type.__swig_setmethods__.get(name,None)
     if method: return method(self,value)
-    self.__dict__[name] = value
+    if (not static) or hasattr(self,name) or (name == "thisown"):
+        self.__dict__[name] = value
+    else:
+        raise AttributeError("You cannot add attributes to %s" % self)
+
+def _swig_setattr(self,class_type,name,value):
+    return _swig_setattr_nondynamic(self,class_type,name,value,0)
 
 def _swig_getattr(self,class_type,name):
     method = class_type.__swig_getmethods__.get(name,None)
@@ -42,6 +48,7 @@ SVN_ERR_XML_ATTRIB_NOT_FOUND = _core.SVN_ERR_XML_ATTRIB_NOT_FOUND
 SVN_ERR_XML_MISSING_ANCESTRY = _core.SVN_ERR_XML_MISSING_ANCESTRY
 SVN_ERR_XML_UNKNOWN_ENCODING = _core.SVN_ERR_XML_UNKNOWN_ENCODING
 SVN_ERR_XML_MALFORMED = _core.SVN_ERR_XML_MALFORMED
+SVN_ERR_XML_UNESCAPABLE_DATA = _core.SVN_ERR_XML_UNESCAPABLE_DATA
 SVN_ERR_IO_INCONSISTENT_EOL = _core.SVN_ERR_IO_INCONSISTENT_EOL
 SVN_ERR_IO_UNKNOWN_EOL = _core.SVN_ERR_IO_UNKNOWN_EOL
 SVN_ERR_IO_CORRUPT_EOL = _core.SVN_ERR_IO_CORRUPT_EOL
@@ -82,6 +89,7 @@ SVN_ERR_WC_INVALID_OP_ON_CWD = _core.SVN_ERR_WC_INVALID_OP_ON_CWD
 SVN_ERR_WC_BAD_ADM_LOG_START = _core.SVN_ERR_WC_BAD_ADM_LOG_START
 SVN_ERR_WC_UNSUPPORTED_FORMAT = _core.SVN_ERR_WC_UNSUPPORTED_FORMAT
 SVN_ERR_WC_BAD_PATH = _core.SVN_ERR_WC_BAD_PATH
+SVN_ERR_WC_INVALID_SCHEDULE = _core.SVN_ERR_WC_INVALID_SCHEDULE
 SVN_ERR_FS_GENERAL = _core.SVN_ERR_FS_GENERAL
 SVN_ERR_FS_CLEANUP = _core.SVN_ERR_FS_CLEANUP
 SVN_ERR_FS_ALREADY_OPEN = _core.SVN_ERR_FS_ALREADY_OPEN
@@ -116,6 +124,16 @@ SVN_ERR_FS_BERKELEY_DB_DEADLOCK = _core.SVN_ERR_FS_BERKELEY_DB_DEADLOCK
 SVN_ERR_FS_TRANSACTION_DEAD = _core.SVN_ERR_FS_TRANSACTION_DEAD
 SVN_ERR_FS_TRANSACTION_NOT_DEAD = _core.SVN_ERR_FS_TRANSACTION_NOT_DEAD
 SVN_ERR_FS_UNKNOWN_FS_TYPE = _core.SVN_ERR_FS_UNKNOWN_FS_TYPE
+SVN_ERR_FS_NO_USER = _core.SVN_ERR_FS_NO_USER
+SVN_ERR_FS_PATH_ALREADY_LOCKED = _core.SVN_ERR_FS_PATH_ALREADY_LOCKED
+SVN_ERR_FS_PATH_NOT_LOCKED = _core.SVN_ERR_FS_PATH_NOT_LOCKED
+SVN_ERR_FS_BAD_LOCK_TOKEN = _core.SVN_ERR_FS_BAD_LOCK_TOKEN
+SVN_ERR_FS_NO_LOCK_TOKEN = _core.SVN_ERR_FS_NO_LOCK_TOKEN
+SVN_ERR_FS_LOCK_OWNER_MISMATCH = _core.SVN_ERR_FS_LOCK_OWNER_MISMATCH
+SVN_ERR_FS_NO_SUCH_LOCK = _core.SVN_ERR_FS_NO_SUCH_LOCK
+SVN_ERR_FS_LOCK_EXPIRED = _core.SVN_ERR_FS_LOCK_EXPIRED
+SVN_ERR_FS_OUT_OF_DATE = _core.SVN_ERR_FS_OUT_OF_DATE
+SVN_ERR_FS_UNSUPPORTED_FORMAT = _core.SVN_ERR_FS_UNSUPPORTED_FORMAT
 SVN_ERR_REPOS_LOCKED = _core.SVN_ERR_REPOS_LOCKED
 SVN_ERR_REPOS_HOOK_FAILURE = _core.SVN_ERR_REPOS_HOOK_FAILURE
 SVN_ERR_REPOS_BAD_ARGS = _core.SVN_ERR_REPOS_BAD_ARGS
@@ -124,6 +142,8 @@ SVN_ERR_REPOS_BAD_REVISION_REPORT = _core.SVN_ERR_REPOS_BAD_REVISION_REPORT
 SVN_ERR_REPOS_UNSUPPORTED_VERSION = _core.SVN_ERR_REPOS_UNSUPPORTED_VERSION
 SVN_ERR_REPOS_DISABLED_FEATURE = _core.SVN_ERR_REPOS_DISABLED_FEATURE
 SVN_ERR_REPOS_POST_COMMIT_HOOK_FAILED = _core.SVN_ERR_REPOS_POST_COMMIT_HOOK_FAILED
+SVN_ERR_REPOS_POST_LOCK_HOOK_FAILED = _core.SVN_ERR_REPOS_POST_LOCK_HOOK_FAILED
+SVN_ERR_REPOS_POST_UNLOCK_HOOK_FAILED = _core.SVN_ERR_REPOS_POST_UNLOCK_HOOK_FAILED
 SVN_ERR_RA_ILLEGAL_URL = _core.SVN_ERR_RA_ILLEGAL_URL
 SVN_ERR_RA_NOT_AUTHORIZED = _core.SVN_ERR_RA_NOT_AUTHORIZED
 SVN_ERR_RA_UNKNOWN_AUTH = _core.SVN_ERR_RA_UNKNOWN_AUTH
@@ -131,6 +151,7 @@ SVN_ERR_RA_NOT_IMPLEMENTED = _core.SVN_ERR_RA_NOT_IMPLEMENTED
 SVN_ERR_RA_OUT_OF_DATE = _core.SVN_ERR_RA_OUT_OF_DATE
 SVN_ERR_RA_NO_REPOS_UUID = _core.SVN_ERR_RA_NO_REPOS_UUID
 SVN_ERR_RA_UNSUPPORTED_ABI_VERSION = _core.SVN_ERR_RA_UNSUPPORTED_ABI_VERSION
+SVN_ERR_RA_NOT_LOCKED = _core.SVN_ERR_RA_NOT_LOCKED
 SVN_ERR_RA_DAV_SOCK_INIT = _core.SVN_ERR_RA_DAV_SOCK_INIT
 SVN_ERR_RA_DAV_CREATING_REQUEST = _core.SVN_ERR_RA_DAV_CREATING_REQUEST
 SVN_ERR_RA_DAV_REQUEST_FAILED = _core.SVN_ERR_RA_DAV_REQUEST_FAILED
@@ -140,6 +161,7 @@ SVN_ERR_RA_DAV_ALREADY_EXISTS = _core.SVN_ERR_RA_DAV_ALREADY_EXISTS
 SVN_ERR_RA_DAV_INVALID_CONFIG_VALUE = _core.SVN_ERR_RA_DAV_INVALID_CONFIG_VALUE
 SVN_ERR_RA_DAV_PATH_NOT_FOUND = _core.SVN_ERR_RA_DAV_PATH_NOT_FOUND
 SVN_ERR_RA_DAV_PROPPATCH_FAILED = _core.SVN_ERR_RA_DAV_PROPPATCH_FAILED
+SVN_ERR_RA_DAV_MALFORMED_DATA = _core.SVN_ERR_RA_DAV_MALFORMED_DATA
 SVN_ERR_RA_LOCAL_REPOS_NOT_FOUND = _core.SVN_ERR_RA_LOCAL_REPOS_NOT_FOUND
 SVN_ERR_RA_LOCAL_REPOS_OPEN_FAILED = _core.SVN_ERR_RA_LOCAL_REPOS_OPEN_FAILED
 SVN_ERR_RA_SVN_CMD_ERR = _core.SVN_ERR_RA_SVN_CMD_ERR
@@ -179,6 +201,7 @@ SVN_ERR_CLIENT_INVALID_RELOCATION = _core.SVN_ERR_CLIENT_INVALID_RELOCATION
 SVN_ERR_CLIENT_REVISION_AUTHOR_CONTAINS_NEWLINE = _core.SVN_ERR_CLIENT_REVISION_AUTHOR_CONTAINS_NEWLINE
 SVN_ERR_CLIENT_PROPERTY_NAME = _core.SVN_ERR_CLIENT_PROPERTY_NAME
 SVN_ERR_CLIENT_UNRELATED_RESOURCES = _core.SVN_ERR_CLIENT_UNRELATED_RESOURCES
+SVN_ERR_CLIENT_MISSING_LOCK_TOKEN = _core.SVN_ERR_CLIENT_MISSING_LOCK_TOKEN
 SVN_ERR_BASE = _core.SVN_ERR_BASE
 SVN_ERR_PLUGIN_LOAD_FAILURE = _core.SVN_ERR_PLUGIN_LOAD_FAILURE
 SVN_ERR_MALFORMED_FILE = _core.SVN_ERR_MALFORMED_FILE
@@ -215,7 +238,7 @@ class svn_error_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_error_t, name)
     def __repr__(self):
-        return "<C svn_error_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_error_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["apr_err"] = _core.svn_error_t_apr_err_set
     __swig_getmethods__["apr_err"] = _core.svn_error_t_apr_err_get
     if _newclass:apr_err = property(_core.svn_error_t_apr_err_get, _core.svn_error_t_apr_err_set)
@@ -240,6 +263,7 @@ class svn_error_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_error_tPtr(svn_error_t):
     def __init__(self, this):
         _swig_setattr(self, svn_error_t, 'this', this)
@@ -252,6 +276,7 @@ svn_node_file = _core.svn_node_file
 svn_node_dir = _core.svn_node_dir
 svn_node_unknown = _core.svn_node_unknown
 SVN_REVNUM_T_FMT = _core.SVN_REVNUM_T_FMT
+SVN_FILESIZE_T_FMT = _core.SVN_FILESIZE_T_FMT
 TRUE = _core.TRUE
 FALSE = _core.FALSE
 svn_nonrecursive = _core.svn_nonrecursive
@@ -262,7 +287,7 @@ class svn_dirent_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_dirent_t, name)
     def __repr__(self):
-        return "<C svn_dirent_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_dirent_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["kind"] = _core.svn_dirent_t_kind_set
     __swig_getmethods__["kind"] = _core.svn_dirent_t_kind_get
     if _newclass:kind = property(_core.svn_dirent_t_kind_get, _core.svn_dirent_t_kind_set)
@@ -288,6 +313,7 @@ class svn_dirent_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_dirent_tPtr(svn_dirent_t):
     def __init__(self, this):
         _swig_setattr(self, svn_dirent_t, 'this', this)
@@ -312,7 +338,7 @@ class svn_log_changed_path_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_log_changed_path_t, name)
     def __repr__(self):
-        return "<C svn_log_changed_path_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_log_changed_path_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["action"] = _core.svn_log_changed_path_t_action_set
     __swig_getmethods__["action"] = _core.svn_log_changed_path_t_action_get
     if _newclass:action = property(_core.svn_log_changed_path_t_action_get, _core.svn_log_changed_path_t_action_set)
@@ -329,6 +355,7 @@ class svn_log_changed_path_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_log_changed_path_tPtr(svn_log_changed_path_t):
     def __init__(self, this):
         _swig_setattr(self, svn_log_changed_path_t, 'this', this)
@@ -341,6 +368,54 @@ SVN_STREAM_CHUNK_SIZE = _core.SVN_STREAM_CHUNK_SIZE
 svn_mime_type_validate = _core.svn_mime_type_validate
 
 svn_mime_type_is_binary = _core.svn_mime_type_is_binary
+class svn_lock_t(_object):
+    __swig_setmethods__ = {}
+    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_lock_t, name, value)
+    __swig_getmethods__ = {}
+    __getattr__ = lambda self, name: _swig_getattr(self, svn_lock_t, name)
+    def __repr__(self):
+        return "<%s.%s; proxy of C svn_lock_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
+    __swig_setmethods__["path"] = _core.svn_lock_t_path_set
+    __swig_getmethods__["path"] = _core.svn_lock_t_path_get
+    if _newclass:path = property(_core.svn_lock_t_path_get, _core.svn_lock_t_path_set)
+    __swig_setmethods__["token"] = _core.svn_lock_t_token_set
+    __swig_getmethods__["token"] = _core.svn_lock_t_token_get
+    if _newclass:token = property(_core.svn_lock_t_token_get, _core.svn_lock_t_token_set)
+    __swig_setmethods__["owner"] = _core.svn_lock_t_owner_set
+    __swig_getmethods__["owner"] = _core.svn_lock_t_owner_get
+    if _newclass:owner = property(_core.svn_lock_t_owner_get, _core.svn_lock_t_owner_set)
+    __swig_setmethods__["comment"] = _core.svn_lock_t_comment_set
+    __swig_getmethods__["comment"] = _core.svn_lock_t_comment_get
+    if _newclass:comment = property(_core.svn_lock_t_comment_get, _core.svn_lock_t_comment_set)
+    __swig_setmethods__["is_dav_comment"] = _core.svn_lock_t_is_dav_comment_set
+    __swig_getmethods__["is_dav_comment"] = _core.svn_lock_t_is_dav_comment_get
+    if _newclass:is_dav_comment = property(_core.svn_lock_t_is_dav_comment_get, _core.svn_lock_t_is_dav_comment_set)
+    __swig_setmethods__["creation_date"] = _core.svn_lock_t_creation_date_set
+    __swig_getmethods__["creation_date"] = _core.svn_lock_t_creation_date_get
+    if _newclass:creation_date = property(_core.svn_lock_t_creation_date_get, _core.svn_lock_t_creation_date_set)
+    __swig_setmethods__["expiration_date"] = _core.svn_lock_t_expiration_date_set
+    __swig_getmethods__["expiration_date"] = _core.svn_lock_t_expiration_date_get
+    if _newclass:expiration_date = property(_core.svn_lock_t_expiration_date_get, _core.svn_lock_t_expiration_date_set)
+    def __init__(self, *args):
+        _swig_setattr(self, svn_lock_t, 'this', _core.new_svn_lock_t(*args))
+        _swig_setattr(self, svn_lock_t, 'thisown', 1)
+    def __del__(self, destroy=_core.delete_svn_lock_t):
+        try:
+            if self.thisown: destroy(self)
+        except: pass
+
+
+class svn_lock_tPtr(svn_lock_t):
+    def __init__(self, this):
+        _swig_setattr(self, svn_lock_t, 'this', this)
+        if not hasattr(self,"thisown"): _swig_setattr(self, svn_lock_t, 'thisown', 0)
+        _swig_setattr(self, svn_lock_t,self.__class__,svn_lock_t)
+_core.svn_lock_t_swigregister(svn_lock_tPtr)
+
+
+svn_lock_create = _core.svn_lock_create
+
+svn_lock_dup = _core.svn_lock_dup
 SWIG_SVN_INVALID_REVNUM = _core.SWIG_SVN_INVALID_REVNUM
 SWIG_SVN_IGNORED_REVNUM = _core.SWIG_SVN_IGNORED_REVNUM
 
@@ -376,7 +451,7 @@ class svn_version_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_version_t, name)
     def __repr__(self):
-        return "<C svn_version_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_version_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["major"] = _core.svn_version_t_major_set
     __swig_getmethods__["major"] = _core.svn_version_t_major_get
     if _newclass:major = property(_core.svn_version_t_major_get, _core.svn_version_t_major_set)
@@ -397,6 +472,7 @@ class svn_version_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_version_tPtr(svn_version_t):
     def __init__(self, this):
         _swig_setattr(self, svn_version_t, 'this', this)
@@ -406,13 +482,15 @@ _core.svn_version_t_swigregister(svn_version_tPtr)
 
 
 svn_ver_compatible = _core.svn_ver_compatible
+
+svn_ver_equal = _core.svn_ver_equal
 class svn_version_checklist_t(_object):
     __swig_setmethods__ = {}
     __setattr__ = lambda self, name, value: _swig_setattr(self, svn_version_checklist_t, name, value)
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_version_checklist_t, name)
     def __repr__(self):
-        return "<C svn_version_checklist_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_version_checklist_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["label"] = _core.svn_version_checklist_t_label_set
     __swig_getmethods__["label"] = _core.svn_version_checklist_t_label_get
     if _newclass:label = property(_core.svn_version_checklist_t_label_get, _core.svn_version_checklist_t_label_set)
@@ -427,6 +505,7 @@ class svn_version_checklist_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_version_checklist_tPtr(svn_version_checklist_t):
     def __init__(self, this):
         _swig_setattr(self, svn_version_checklist_t, 'this', this)
@@ -468,6 +547,8 @@ SVN_PROP_EOL_STYLE = _core.SVN_PROP_EOL_STYLE
 SVN_PROP_KEYWORDS = _core.SVN_PROP_KEYWORDS
 SVN_PROP_EXECUTABLE = _core.SVN_PROP_EXECUTABLE
 SVN_PROP_EXECUTABLE_VALUE = _core.SVN_PROP_EXECUTABLE_VALUE
+SVN_PROP_NEEDS_LOCK = _core.SVN_PROP_NEEDS_LOCK
+SVN_PROP_NEEDS_LOCK_VALUE = _core.SVN_PROP_NEEDS_LOCK_VALUE
 SVN_PROP_SPECIAL = _core.SVN_PROP_SPECIAL
 SVN_PROP_SPECIAL_VALUE = _core.SVN_PROP_SPECIAL_VALUE
 SVN_PROP_EXTERNALS = _core.SVN_PROP_EXTERNALS
@@ -477,11 +558,13 @@ SVN_PROP_ENTRY_COMMITTED_REV = _core.SVN_PROP_ENTRY_COMMITTED_REV
 SVN_PROP_ENTRY_COMMITTED_DATE = _core.SVN_PROP_ENTRY_COMMITTED_DATE
 SVN_PROP_ENTRY_LAST_AUTHOR = _core.SVN_PROP_ENTRY_LAST_AUTHOR
 SVN_PROP_ENTRY_UUID = _core.SVN_PROP_ENTRY_UUID
+SVN_PROP_ENTRY_LOCK_TOKEN = _core.SVN_PROP_ENTRY_LOCK_TOKEN
 SVN_PROP_CUSTOM_PREFIX = _core.SVN_PROP_CUSTOM_PREFIX
 SVN_PROP_REVISION_AUTHOR = _core.SVN_PROP_REVISION_AUTHOR
 SVN_PROP_REVISION_LOG = _core.SVN_PROP_REVISION_LOG
 SVN_PROP_REVISION_DATE = _core.SVN_PROP_REVISION_DATE
 SVN_PROP_REVISION_ORIG_DATE = _core.SVN_PROP_REVISION_ORIG_DATE
+SVN_PROP_REVISION_AUTOVERSIONED = _core.SVN_PROP_REVISION_AUTOVERSIONED
 SVN_OPT_MAX_ALIASES = _core.SVN_OPT_MAX_ALIASES
 SVN_OPT_MAX_OPTIONS = _core.SVN_OPT_MAX_OPTIONS
 SVN_OPT_FIRST_LONGOPT_ID = _core.SVN_OPT_FIRST_LONGOPT_ID
@@ -491,7 +574,7 @@ class svn_opt_subcommand_desc_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_opt_subcommand_desc_t, name)
     def __repr__(self):
-        return "<C svn_opt_subcommand_desc_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_opt_subcommand_desc_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["name"] = _core.svn_opt_subcommand_desc_t_name_set
     __swig_getmethods__["name"] = _core.svn_opt_subcommand_desc_t_name_get
     if _newclass:name = property(_core.svn_opt_subcommand_desc_t_name_get, _core.svn_opt_subcommand_desc_t_name_set)
@@ -515,6 +598,7 @@ class svn_opt_subcommand_desc_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_opt_subcommand_desc_tPtr(svn_opt_subcommand_desc_t):
     def __init__(self, this):
         _swig_setattr(self, svn_opt_subcommand_desc_t, 'this', this)
@@ -546,7 +630,7 @@ class svn_opt_revision_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_opt_revision_t, name)
     def __repr__(self):
-        return "<C svn_opt_revision_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_opt_revision_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["kind"] = _core.svn_opt_revision_t_kind_set
     __swig_getmethods__["kind"] = _core.svn_opt_revision_t_kind_get
     if _newclass:kind = property(_core.svn_opt_revision_t_kind_get, _core.svn_opt_revision_t_kind_set)
@@ -560,6 +644,7 @@ class svn_opt_revision_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_opt_revision_tPtr(svn_opt_revision_t):
     def __init__(self, this):
         _swig_setattr(self, svn_opt_revision_t, 'this', this)
@@ -573,7 +658,7 @@ class svn_opt_revision_t_value(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_opt_revision_t_value, name)
     def __repr__(self):
-        return "<C svn_opt_revision_t_value instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_opt_revision_t_value instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["number"] = _core.svn_opt_revision_t_value_number_set
     __swig_getmethods__["number"] = _core.svn_opt_revision_t_value_number_get
     if _newclass:number = property(_core.svn_opt_revision_t_value_number_get, _core.svn_opt_revision_t_value_number_set)
@@ -588,6 +673,7 @@ class svn_opt_revision_t_value(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_opt_revision_t_valuePtr(svn_opt_revision_t_value):
     def __init__(self, this):
         _swig_setattr(self, svn_opt_revision_t_value, 'this', this)
@@ -598,6 +684,8 @@ _core.svn_opt_revision_t_value_swigregister(svn_opt_revision_t_valuePtr)
 
 svn_opt_parse_revision = _core.svn_opt_parse_revision
 
+svn_opt_args_to_target_array2 = _core.svn_opt_args_to_target_array2
+
 svn_opt_args_to_target_array = _core.svn_opt_args_to_target_array
 
 svn_opt_push_implicit_dot_target = _core.svn_opt_push_implicit_dot_target
@@ -615,7 +703,7 @@ class svn_auth_provider_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_auth_provider_t, name)
     def __repr__(self):
-        return "<C svn_auth_provider_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_auth_provider_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["cred_kind"] = _core.svn_auth_provider_t_cred_kind_set
     __swig_getmethods__["cred_kind"] = _core.svn_auth_provider_t_cred_kind_get
     if _newclass:cred_kind = property(_core.svn_auth_provider_t_cred_kind_get, _core.svn_auth_provider_t_cred_kind_set)
@@ -636,6 +724,7 @@ class svn_auth_provider_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_auth_provider_tPtr(svn_auth_provider_t):
     def __init__(self, this):
         _swig_setattr(self, svn_auth_provider_t, 'this', this)
@@ -649,7 +738,7 @@ class svn_auth_provider_object_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_auth_provider_object_t, name)
     def __repr__(self):
-        return "<C svn_auth_provider_object_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_auth_provider_object_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["vtable"] = _core.svn_auth_provider_object_t_vtable_set
     __swig_getmethods__["vtable"] = _core.svn_auth_provider_object_t_vtable_get
     if _newclass:vtable = property(_core.svn_auth_provider_object_t_vtable_get, _core.svn_auth_provider_object_t_vtable_set)
@@ -664,6 +753,7 @@ class svn_auth_provider_object_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_auth_provider_object_tPtr(svn_auth_provider_object_t):
     def __init__(self, this):
         _swig_setattr(self, svn_auth_provider_object_t, 'this', this)
@@ -678,7 +768,7 @@ class svn_auth_cred_simple_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_auth_cred_simple_t, name)
     def __repr__(self):
-        return "<C svn_auth_cred_simple_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_auth_cred_simple_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["username"] = _core.svn_auth_cred_simple_t_username_set
     __swig_getmethods__["username"] = _core.svn_auth_cred_simple_t_username_get
     if _newclass:username = property(_core.svn_auth_cred_simple_t_username_get, _core.svn_auth_cred_simple_t_username_set)
@@ -696,6 +786,7 @@ class svn_auth_cred_simple_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_auth_cred_simple_tPtr(svn_auth_cred_simple_t):
     def __init__(self, this):
         _swig_setattr(self, svn_auth_cred_simple_t, 'this', this)
@@ -710,7 +801,7 @@ class svn_auth_cred_username_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_auth_cred_username_t, name)
     def __repr__(self):
-        return "<C svn_auth_cred_username_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_auth_cred_username_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["username"] = _core.svn_auth_cred_username_t_username_set
     __swig_getmethods__["username"] = _core.svn_auth_cred_username_t_username_get
     if _newclass:username = property(_core.svn_auth_cred_username_t_username_get, _core.svn_auth_cred_username_t_username_set)
@@ -725,6 +816,7 @@ class svn_auth_cred_username_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_auth_cred_username_tPtr(svn_auth_cred_username_t):
     def __init__(self, this):
         _swig_setattr(self, svn_auth_cred_username_t, 'this', this)
@@ -739,7 +831,7 @@ class svn_auth_cred_ssl_client_cert_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_auth_cred_ssl_client_cert_t, name)
     def __repr__(self):
-        return "<C svn_auth_cred_ssl_client_cert_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_auth_cred_ssl_client_cert_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["cert_file"] = _core.svn_auth_cred_ssl_client_cert_t_cert_file_set
     __swig_getmethods__["cert_file"] = _core.svn_auth_cred_ssl_client_cert_t_cert_file_get
     if _newclass:cert_file = property(_core.svn_auth_cred_ssl_client_cert_t_cert_file_get, _core.svn_auth_cred_ssl_client_cert_t_cert_file_set)
@@ -754,6 +846,7 @@ class svn_auth_cred_ssl_client_cert_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_auth_cred_ssl_client_cert_tPtr(svn_auth_cred_ssl_client_cert_t):
     def __init__(self, this):
         _swig_setattr(self, svn_auth_cred_ssl_client_cert_t, 'this', this)
@@ -768,7 +861,7 @@ class svn_auth_cred_ssl_client_cert_pw_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_auth_cred_ssl_client_cert_pw_t, name)
     def __repr__(self):
-        return "<C svn_auth_cred_ssl_client_cert_pw_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_auth_cred_ssl_client_cert_pw_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["password"] = _core.svn_auth_cred_ssl_client_cert_pw_t_password_set
     __swig_getmethods__["password"] = _core.svn_auth_cred_ssl_client_cert_pw_t_password_get
     if _newclass:password = property(_core.svn_auth_cred_ssl_client_cert_pw_t_password_get, _core.svn_auth_cred_ssl_client_cert_pw_t_password_set)
@@ -783,6 +876,7 @@ class svn_auth_cred_ssl_client_cert_pw_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_auth_cred_ssl_client_cert_pw_tPtr(svn_auth_cred_ssl_client_cert_pw_t):
     def __init__(self, this):
         _swig_setattr(self, svn_auth_cred_ssl_client_cert_pw_t, 'this', this)
@@ -797,7 +891,7 @@ class svn_auth_ssl_server_cert_info_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_auth_ssl_server_cert_info_t, name)
     def __repr__(self):
-        return "<C svn_auth_ssl_server_cert_info_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_auth_ssl_server_cert_info_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["hostname"] = _core.svn_auth_ssl_server_cert_info_t_hostname_set
     __swig_getmethods__["hostname"] = _core.svn_auth_ssl_server_cert_info_t_hostname_get
     if _newclass:hostname = property(_core.svn_auth_ssl_server_cert_info_t_hostname_get, _core.svn_auth_ssl_server_cert_info_t_hostname_set)
@@ -824,6 +918,7 @@ class svn_auth_ssl_server_cert_info_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_auth_ssl_server_cert_info_tPtr(svn_auth_ssl_server_cert_info_t):
     def __init__(self, this):
         _swig_setattr(self, svn_auth_ssl_server_cert_info_t, 'this', this)
@@ -837,7 +932,7 @@ class svn_auth_cred_ssl_server_trust_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_auth_cred_ssl_server_trust_t, name)
     def __repr__(self):
-        return "<C svn_auth_cred_ssl_server_trust_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_auth_cred_ssl_server_trust_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["may_save"] = _core.svn_auth_cred_ssl_server_trust_t_may_save_set
     __swig_getmethods__["may_save"] = _core.svn_auth_cred_ssl_server_trust_t_may_save_get
     if _newclass:may_save = property(_core.svn_auth_cred_ssl_server_trust_t_may_save_get, _core.svn_auth_cred_ssl_server_trust_t_may_save_set)
@@ -852,6 +947,7 @@ class svn_auth_cred_ssl_server_trust_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_auth_cred_ssl_server_trust_tPtr(svn_auth_cred_ssl_server_trust_t):
     def __init__(self, this):
         _swig_setattr(self, svn_auth_cred_ssl_server_trust_t, 'this', this)
@@ -868,8 +964,6 @@ SVN_AUTH_SSL_OTHER = _core.SVN_AUTH_SSL_OTHER
 svn_auth_open = _core.svn_auth_open
 
 svn_auth_set_parameter = _core.svn_auth_set_parameter
-
-svn_auth_get_parameter = _core.svn_auth_get_parameter
 SVN_AUTH_PARAM_PREFIX = _core.SVN_AUTH_PARAM_PREFIX
 SVN_AUTH_PARAM_DEFAULT_USERNAME = _core.SVN_AUTH_PARAM_DEFAULT_USERNAME
 SVN_AUTH_PARAM_DEFAULT_PASSWORD = _core.SVN_AUTH_PARAM_DEFAULT_PASSWORD
@@ -917,6 +1011,7 @@ SVN_CONFIG_OPTION_LOG_ENCODING = _core.SVN_CONFIG_OPTION_LOG_ENCODING
 SVN_CONFIG_OPTION_USE_COMMIT_TIMES = _core.SVN_CONFIG_OPTION_USE_COMMIT_TIMES
 SVN_CONFIG_OPTION_TEMPLATE_ROOT = _core.SVN_CONFIG_OPTION_TEMPLATE_ROOT
 SVN_CONFIG_OPTION_ENABLE_AUTO_PROPS = _core.SVN_CONFIG_OPTION_ENABLE_AUTO_PROPS
+SVN_CONFIG_OPTION_NO_UNLOCK = _core.SVN_CONFIG_OPTION_NO_UNLOCK
 SVN_CONFIG_SECTION_TUNNELS = _core.SVN_CONFIG_SECTION_TUNNELS
 SVN_CONFIG_SECTION_AUTO_PROPS = _core.SVN_CONFIG_SECTION_AUTO_PROPS
 SVN_CONFIG_SECTION_GENERAL = _core.SVN_CONFIG_SECTION_GENERAL
@@ -960,34 +1055,38 @@ svn_config_read_auth_data = _core.svn_config_read_auth_data
 
 svn_config_write_auth_data = _core.svn_config_write_auth_data
 
-svn_io_check_special_path = _core.svn_io_check_special_path
+svn_utf_initialize = _core.svn_utf_initialize
+
+svn_utf_stringbuf_to_utf8 = _core.svn_utf_stringbuf_to_utf8
+
+svn_utf_string_to_utf8 = _core.svn_utf_string_to_utf8
+
+svn_utf_cstring_to_utf8 = _core.svn_utf_cstring_to_utf8
+
+svn_utf_cstring_to_utf8_ex = _core.svn_utf_cstring_to_utf8_ex
+
+svn_utf_stringbuf_from_utf8 = _core.svn_utf_stringbuf_from_utf8
+
+svn_utf_string_from_utf8 = _core.svn_utf_string_from_utf8
+
+svn_utf_cstring_from_utf8 = _core.svn_utf_cstring_from_utf8
+
+svn_utf_cstring_from_utf8_ex = _core.svn_utf_cstring_from_utf8_ex
+
+svn_utf_cstring_from_utf8_fuzzy = _core.svn_utf_cstring_from_utf8_fuzzy
+
+svn_utf_cstring_from_utf8_stringbuf = _core.svn_utf_cstring_from_utf8_stringbuf
+
+svn_utf_cstring_from_utf8_string = _core.svn_utf_cstring_from_utf8_string
 
 svn_io_open_unique_file = _core.svn_io_open_unique_file
 
-svn_io_create_unique_link = _core.svn_io_create_unique_link
-
-svn_io_read_link = _core.svn_io_read_link
-
-svn_io_copy_link = _core.svn_io_copy_link
+svn_io_set_file_read_write_carefully = _core.svn_io_set_file_read_write_carefully
 
 svn_io_file_checksum = _core.svn_io_file_checksum
 
 svn_io_files_contents_same_p = _core.svn_io_files_contents_same_p
 
-svn_io_file_lock2 = _core.svn_io_file_lock2
-
-svn_io_file_flush_to_disk = _core.svn_io_file_flush_to_disk
-
-svn_stream_create = _core.svn_stream_create
-
-svn_stream_set_baton = _core.svn_stream_set_baton
-
-svn_stream_set_read = _core.svn_stream_set_read
-
-svn_stream_set_write = _core.svn_stream_set_write
-
-svn_stream_set_close = _core.svn_stream_set_close
-
 svn_stream_empty = _core.svn_stream_empty
 
 svn_stream_from_aprfile = _core.svn_stream_from_aprfile
@@ -1013,8 +1112,6 @@ svn_stringbuf_from_file = _core.svn_stringbuf_from_file
 svn_stringbuf_from_aprfile = _core.svn_stringbuf_from_aprfile
 
 svn_io_detect_mimetype = _core.svn_io_detect_mimetype
-
-svn_io_dir_make_sgid = _core.svn_io_dir_make_sgid
 SubversionException = _core.SubversionException
 
 
