@@ -4,7 +4,7 @@
 
 import _repos
 
-def _swig_setattr(self,class_type,name,value):
+def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
     if (name == "this"):
         if isinstance(value, class_type):
             self.__dict__[name] = value.this
@@ -13,7 +13,13 @@ def _swig_setattr(self,class_type,name,value):
             return
     method = class_type.__swig_setmethods__.get(name,None)
     if method: return method(self,value)
-    self.__dict__[name] = value
+    if (not static) or hasattr(self,name) or (name == "thisown"):
+        self.__dict__[name] = value
+    else:
+        raise AttributeError("You cannot add attributes to %s" % self)
+
+def _swig_setattr(self,class_type,name,value):
+    return _swig_setattr_nondynamic(self,class_type,name,value,0)
 
 def _swig_getattr(self,class_type,name):
     method = class_type.__swig_getmethods__.get(name,None)
@@ -79,10 +85,22 @@ svn_repos_pre_revprop_change_hook = _repos.svn_repos_pre_revprop_change_hook
 
 svn_repos_post_revprop_change_hook = _repos.svn_repos_post_revprop_change_hook
 
+svn_repos_pre_lock_hook = _repos.svn_repos_pre_lock_hook
+
+svn_repos_post_lock_hook = _repos.svn_repos_post_lock_hook
+
+svn_repos_pre_unlock_hook = _repos.svn_repos_pre_unlock_hook
+
+svn_repos_post_unlock_hook = _repos.svn_repos_post_unlock_hook
+
 svn_repos_begin_report = _repos.svn_repos_begin_report
 
+svn_repos_set_path2 = _repos.svn_repos_set_path2
+
 svn_repos_set_path = _repos.svn_repos_set_path
 
+svn_repos_link_path2 = _repos.svn_repos_link_path2
+
 svn_repos_link_path = _repos.svn_repos_link_path
 
 svn_repos_delete_path = _repos.svn_repos_delete_path
@@ -95,18 +113,24 @@ svn_repos_dir_delta = _repos.svn_repos_dir_delta
 
 svn_repos_replay = _repos.svn_repos_replay
 
+svn_repos_get_commit_editor2 = _repos.svn_repos_get_commit_editor2
+
 svn_repos_get_commit_editor = _repos.svn_repos_get_commit_editor
 
 svn_repos_dated_revision = _repos.svn_repos_dated_revision
 
 svn_repos_get_committed_info = _repos.svn_repos_get_committed_info
 
+svn_repos_stat = _repos.svn_repos_stat
+
 svn_repos_history2 = _repos.svn_repos_history2
 
 svn_repos_history = _repos.svn_repos_history
 
 svn_repos_trace_node_locations = _repos.svn_repos_trace_node_locations
 
+svn_repos_get_logs3 = _repos.svn_repos_get_logs3
+
 svn_repos_get_logs2 = _repos.svn_repos_get_logs2
 
 svn_repos_get_logs = _repos.svn_repos_get_logs
@@ -119,6 +143,12 @@ svn_repos_fs_begin_txn_for_commit = _repos.svn_repos_fs_begin_txn_for_commit
 
 svn_repos_fs_begin_txn_for_update = _repos.svn_repos_fs_begin_txn_for_update
 
+svn_repos_fs_lock = _repos.svn_repos_fs_lock
+
+svn_repos_fs_unlock = _repos.svn_repos_fs_unlock
+
+svn_repos_fs_get_locks = _repos.svn_repos_fs_get_locks
+
 svn_repos_fs_change_rev_prop2 = _repos.svn_repos_fs_change_rev_prop2
 
 svn_repos_fs_change_rev_prop = _repos.svn_repos_fs_change_rev_prop
@@ -137,7 +167,7 @@ class svn_repos_node_t(_object):
     __getattr__ = lambda self, name: _swig_getattr(self, svn_repos_node_t, name)
     def __init__(self): raise RuntimeError, "No constructor defined"
     def __repr__(self):
-        return "<C svn_repos_node_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_repos_node_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["kind"] = _repos.svn_repos_node_t_kind_set
     __swig_getmethods__["kind"] = _repos.svn_repos_node_t_kind_get
     if _newclass:kind = property(_repos.svn_repos_node_t_kind_get, _repos.svn_repos_node_t_kind_set)
@@ -208,6 +238,8 @@ svn_repos_dump_fs2 = _repos.svn_repos_dump_fs2
 
 svn_repos_dump_fs = _repos.svn_repos_dump_fs
 
+svn_repos_load_fs2 = _repos.svn_repos_load_fs2
+
 svn_repos_load_fs = _repos.svn_repos_load_fs
 class svn_repos_parser_fns2_t(_object):
     __swig_setmethods__ = {}
@@ -216,7 +248,7 @@ class svn_repos_parser_fns2_t(_object):
     __getattr__ = lambda self, name: _swig_getattr(self, svn_repos_parser_fns2_t, name)
     def __init__(self): raise RuntimeError, "No constructor defined"
     def __repr__(self):
-        return "<C svn_repos_parser_fns2_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_repos_parser_fns2_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["new_revision_record"] = _repos.svn_repos_parser_fns2_t_new_revision_record_set
     __swig_getmethods__["new_revision_record"] = _repos.svn_repos_parser_fns2_t_new_revision_record_get
     if _newclass:new_revision_record = property(_repos.svn_repos_parser_fns2_t_new_revision_record_get, _repos.svn_repos_parser_fns2_t_new_revision_record_set)
@@ -269,7 +301,7 @@ class svn_repos_parser_fns_t(_object):
     __getattr__ = lambda self, name: _swig_getattr(self, svn_repos_parser_fns_t, name)
     def __init__(self): raise RuntimeError, "No constructor defined"
     def __repr__(self):
-        return "<C svn_repos_parser_fns_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_repos_parser_fns_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["new_revision_record"] = _repos.svn_repos_parser_fns_t_new_revision_record_set
     __swig_getmethods__["new_revision_record"] = _repos.svn_repos_parser_fns_t_new_revision_record_get
     if _newclass:new_revision_record = property(_repos.svn_repos_parser_fns_t_new_revision_record_get, _repos.svn_repos_parser_fns_t_new_revision_record_set)
