@@ -4,7 +4,7 @@
 
 import _wc
 
-def _swig_setattr(self,class_type,name,value):
+def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
     if (name == "this"):
         if isinstance(value, class_type):
             self.__dict__[name] = value.this
@@ -13,7 +13,13 @@ def _swig_setattr(self,class_type,name,value):
             return
     method = class_type.__swig_setmethods__.get(name,None)
     if method: return method(self,value)
-    self.__dict__[name] = value
+    if (not static) or hasattr(self,name) or (name == "thisown"):
+        self.__dict__[name] = value
+    else:
+        raise AttributeError("You cannot add attributes to %s" % self)
+
+def _swig_setattr(self,class_type,name,value):
+    return _swig_setattr_nondynamic(self,class_type,name,value,0)
 
 def _swig_getattr(self,class_type,name):
     method = class_type.__swig_getmethods__.get(name,None)
@@ -34,18 +40,26 @@ import delta
 
 svn_wc_version = _wc.svn_wc_version
 
+svn_wc_adm_open3 = _wc.svn_wc_adm_open3
+
 svn_wc_adm_open2 = _wc.svn_wc_adm_open2
 
 svn_wc_adm_open = _wc.svn_wc_adm_open
 
+svn_wc_adm_probe_open3 = _wc.svn_wc_adm_probe_open3
+
 svn_wc_adm_probe_open2 = _wc.svn_wc_adm_probe_open2
 
 svn_wc_adm_probe_open = _wc.svn_wc_adm_probe_open
 
+svn_wc_adm_open_anchor = _wc.svn_wc_adm_open_anchor
+
 svn_wc_adm_retrieve = _wc.svn_wc_adm_retrieve
 
 svn_wc_adm_probe_retrieve = _wc.svn_wc_adm_probe_retrieve
 
+svn_wc_adm_probe_try3 = _wc.svn_wc_adm_probe_try3
+
 svn_wc_adm_probe_try2 = _wc.svn_wc_adm_probe_try2
 
 svn_wc_adm_probe_try = _wc.svn_wc_adm_probe_try
@@ -69,7 +83,7 @@ class svn_wc_external_item_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_wc_external_item_t, name)
     def __repr__(self):
-        return "<C svn_wc_external_item_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_wc_external_item_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["target_dir"] = _wc.svn_wc_external_item_t_target_dir_set
     __swig_getmethods__["target_dir"] = _wc.svn_wc_external_item_t_target_dir_get
     if _newclass:target_dir = property(_wc.svn_wc_external_item_t_target_dir_get, _wc.svn_wc_external_item_t_target_dir_set)
@@ -87,6 +101,7 @@ class svn_wc_external_item_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_wc_external_item_tPtr(svn_wc_external_item_t):
     def __init__(self, this):
         _swig_setattr(self, svn_wc_external_item_t, 'this', this)
@@ -119,6 +134,10 @@ svn_wc_notify_commit_deleted = _wc.svn_wc_notify_commit_deleted
 svn_wc_notify_commit_replaced = _wc.svn_wc_notify_commit_replaced
 svn_wc_notify_commit_postfix_txdelta = _wc.svn_wc_notify_commit_postfix_txdelta
 svn_wc_notify_blame_revision = _wc.svn_wc_notify_blame_revision
+svn_wc_notify_locked = _wc.svn_wc_notify_locked
+svn_wc_notify_unlocked = _wc.svn_wc_notify_unlocked
+svn_wc_notify_failed_lock = _wc.svn_wc_notify_failed_lock
+svn_wc_notify_failed_unlock = _wc.svn_wc_notify_failed_unlock
 svn_wc_notify_state_inapplicable = _wc.svn_wc_notify_state_inapplicable
 svn_wc_notify_state_unknown = _wc.svn_wc_notify_state_unknown
 svn_wc_notify_state_unchanged = _wc.svn_wc_notify_state_unchanged
@@ -127,13 +146,116 @@ svn_wc_notify_state_obstructed = _wc.svn_wc_notify_state_obstructed
 svn_wc_notify_state_changed = _wc.svn_wc_notify_state_changed
 svn_wc_notify_state_merged = _wc.svn_wc_notify_state_merged
 svn_wc_notify_state_conflicted = _wc.svn_wc_notify_state_conflicted
+svn_wc_notify_lock_state_inapplicable = _wc.svn_wc_notify_lock_state_inapplicable
+svn_wc_notify_lock_state_unknown = _wc.svn_wc_notify_lock_state_unknown
+svn_wc_notify_lock_state_unchanged = _wc.svn_wc_notify_lock_state_unchanged
+svn_wc_notify_lock_state_locked = _wc.svn_wc_notify_lock_state_locked
+svn_wc_notify_lock_state_unlocked = _wc.svn_wc_notify_lock_state_unlocked
+class svn_wc_notify_t(_object):
+    __swig_setmethods__ = {}
+    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_wc_notify_t, name, value)
+    __swig_getmethods__ = {}
+    __getattr__ = lambda self, name: _swig_getattr(self, svn_wc_notify_t, name)
+    def __repr__(self):
+        return "<%s.%s; proxy of C svn_wc_notify_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
+    __swig_setmethods__["path"] = _wc.svn_wc_notify_t_path_set
+    __swig_getmethods__["path"] = _wc.svn_wc_notify_t_path_get
+    if _newclass:path = property(_wc.svn_wc_notify_t_path_get, _wc.svn_wc_notify_t_path_set)
+    __swig_setmethods__["action"] = _wc.svn_wc_notify_t_action_set
+    __swig_getmethods__["action"] = _wc.svn_wc_notify_t_action_get
+    if _newclass:action = property(_wc.svn_wc_notify_t_action_get, _wc.svn_wc_notify_t_action_set)
+    __swig_setmethods__["kind"] = _wc.svn_wc_notify_t_kind_set
+    __swig_getmethods__["kind"] = _wc.svn_wc_notify_t_kind_get
+    if _newclass:kind = property(_wc.svn_wc_notify_t_kind_get, _wc.svn_wc_notify_t_kind_set)
+    __swig_setmethods__["mime_type"] = _wc.svn_wc_notify_t_mime_type_set
+    __swig_getmethods__["mime_type"] = _wc.svn_wc_notify_t_mime_type_get
+    if _newclass:mime_type = property(_wc.svn_wc_notify_t_mime_type_get, _wc.svn_wc_notify_t_mime_type_set)
+    __swig_setmethods__["lock"] = _wc.svn_wc_notify_t_lock_set
+    __swig_getmethods__["lock"] = _wc.svn_wc_notify_t_lock_get
+    if _newclass:lock = property(_wc.svn_wc_notify_t_lock_get, _wc.svn_wc_notify_t_lock_set)
+    __swig_setmethods__["err"] = _wc.svn_wc_notify_t_err_set
+    __swig_getmethods__["err"] = _wc.svn_wc_notify_t_err_get
+    if _newclass:err = property(_wc.svn_wc_notify_t_err_get, _wc.svn_wc_notify_t_err_set)
+    __swig_setmethods__["content_state"] = _wc.svn_wc_notify_t_content_state_set
+    __swig_getmethods__["content_state"] = _wc.svn_wc_notify_t_content_state_get
+    if _newclass:content_state = property(_wc.svn_wc_notify_t_content_state_get, _wc.svn_wc_notify_t_content_state_set)
+    __swig_setmethods__["prop_state"] = _wc.svn_wc_notify_t_prop_state_set
+    __swig_getmethods__["prop_state"] = _wc.svn_wc_notify_t_prop_state_get
+    if _newclass:prop_state = property(_wc.svn_wc_notify_t_prop_state_get, _wc.svn_wc_notify_t_prop_state_set)
+    __swig_setmethods__["lock_state"] = _wc.svn_wc_notify_t_lock_state_set
+    __swig_getmethods__["lock_state"] = _wc.svn_wc_notify_t_lock_state_get
+    if _newclass:lock_state = property(_wc.svn_wc_notify_t_lock_state_get, _wc.svn_wc_notify_t_lock_state_set)
+    __swig_setmethods__["revision"] = _wc.svn_wc_notify_t_revision_set
+    __swig_getmethods__["revision"] = _wc.svn_wc_notify_t_revision_get
+    if _newclass:revision = property(_wc.svn_wc_notify_t_revision_get, _wc.svn_wc_notify_t_revision_set)
+    def __init__(self, *args):
+        _swig_setattr(self, svn_wc_notify_t, 'this', _wc.new_svn_wc_notify_t(*args))
+        _swig_setattr(self, svn_wc_notify_t, 'thisown', 1)
+    def __del__(self, destroy=_wc.delete_svn_wc_notify_t):
+        try:
+            if self.thisown: destroy(self)
+        except: pass
+
+
+class svn_wc_notify_tPtr(svn_wc_notify_t):
+    def __init__(self, this):
+        _swig_setattr(self, svn_wc_notify_t, 'this', this)
+        if not hasattr(self,"thisown"): _swig_setattr(self, svn_wc_notify_t, 'thisown', 0)
+        _swig_setattr(self, svn_wc_notify_t,self.__class__,svn_wc_notify_t)
+_wc.svn_wc_notify_t_swigregister(svn_wc_notify_tPtr)
+
+
+svn_wc_create_notify = _wc.svn_wc_create_notify
+
+svn_wc_dup_notify = _wc.svn_wc_dup_notify
+class svn_wc_diff_callbacks2_t(_object):
+    __swig_setmethods__ = {}
+    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_wc_diff_callbacks2_t, name, value)
+    __swig_getmethods__ = {}
+    __getattr__ = lambda self, name: _swig_getattr(self, svn_wc_diff_callbacks2_t, name)
+    def __repr__(self):
+        return "<%s.%s; proxy of C svn_wc_diff_callbacks2_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
+    __swig_setmethods__["file_changed"] = _wc.svn_wc_diff_callbacks2_t_file_changed_set
+    __swig_getmethods__["file_changed"] = _wc.svn_wc_diff_callbacks2_t_file_changed_get
+    if _newclass:file_changed = property(_wc.svn_wc_diff_callbacks2_t_file_changed_get, _wc.svn_wc_diff_callbacks2_t_file_changed_set)
+    __swig_setmethods__["file_added"] = _wc.svn_wc_diff_callbacks2_t_file_added_set
+    __swig_getmethods__["file_added"] = _wc.svn_wc_diff_callbacks2_t_file_added_get
+    if _newclass:file_added = property(_wc.svn_wc_diff_callbacks2_t_file_added_get, _wc.svn_wc_diff_callbacks2_t_file_added_set)
+    __swig_setmethods__["file_deleted"] = _wc.svn_wc_diff_callbacks2_t_file_deleted_set
+    __swig_getmethods__["file_deleted"] = _wc.svn_wc_diff_callbacks2_t_file_deleted_get
+    if _newclass:file_deleted = property(_wc.svn_wc_diff_callbacks2_t_file_deleted_get, _wc.svn_wc_diff_callbacks2_t_file_deleted_set)
+    __swig_setmethods__["dir_added"] = _wc.svn_wc_diff_callbacks2_t_dir_added_set
+    __swig_getmethods__["dir_added"] = _wc.svn_wc_diff_callbacks2_t_dir_added_get
+    if _newclass:dir_added = property(_wc.svn_wc_diff_callbacks2_t_dir_added_get, _wc.svn_wc_diff_callbacks2_t_dir_added_set)
+    __swig_setmethods__["dir_deleted"] = _wc.svn_wc_diff_callbacks2_t_dir_deleted_set
+    __swig_getmethods__["dir_deleted"] = _wc.svn_wc_diff_callbacks2_t_dir_deleted_get
+    if _newclass:dir_deleted = property(_wc.svn_wc_diff_callbacks2_t_dir_deleted_get, _wc.svn_wc_diff_callbacks2_t_dir_deleted_set)
+    __swig_setmethods__["dir_props_changed"] = _wc.svn_wc_diff_callbacks2_t_dir_props_changed_set
+    __swig_getmethods__["dir_props_changed"] = _wc.svn_wc_diff_callbacks2_t_dir_props_changed_get
+    if _newclass:dir_props_changed = property(_wc.svn_wc_diff_callbacks2_t_dir_props_changed_get, _wc.svn_wc_diff_callbacks2_t_dir_props_changed_set)
+    def __init__(self, *args):
+        _swig_setattr(self, svn_wc_diff_callbacks2_t, 'this', _wc.new_svn_wc_diff_callbacks2_t(*args))
+        _swig_setattr(self, svn_wc_diff_callbacks2_t, 'thisown', 1)
+    def __del__(self, destroy=_wc.delete_svn_wc_diff_callbacks2_t):
+        try:
+            if self.thisown: destroy(self)
+        except: pass
+
+
+class svn_wc_diff_callbacks2_tPtr(svn_wc_diff_callbacks2_t):
+    def __init__(self, this):
+        _swig_setattr(self, svn_wc_diff_callbacks2_t, 'this', this)
+        if not hasattr(self,"thisown"): _swig_setattr(self, svn_wc_diff_callbacks2_t, 'thisown', 0)
+        _swig_setattr(self, svn_wc_diff_callbacks2_t,self.__class__,svn_wc_diff_callbacks2_t)
+_wc.svn_wc_diff_callbacks2_t_swigregister(svn_wc_diff_callbacks2_tPtr)
+
 class svn_wc_diff_callbacks_t(_object):
     __swig_setmethods__ = {}
     __setattr__ = lambda self, name, value: _swig_setattr(self, svn_wc_diff_callbacks_t, name, value)
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_wc_diff_callbacks_t, name)
     def __repr__(self):
-        return "<C svn_wc_diff_callbacks_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_wc_diff_callbacks_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["file_changed"] = _wc.svn_wc_diff_callbacks_t_file_changed_set
     __swig_getmethods__["file_changed"] = _wc.svn_wc_diff_callbacks_t_file_changed_get
     if _newclass:file_changed = property(_wc.svn_wc_diff_callbacks_t_file_changed_get, _wc.svn_wc_diff_callbacks_t_file_changed_set)
@@ -160,6 +282,7 @@ class svn_wc_diff_callbacks_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_wc_diff_callbacks_tPtr(svn_wc_diff_callbacks_t):
     def __init__(self, this):
         _swig_setattr(self, svn_wc_diff_callbacks_t, 'this', this)
@@ -186,7 +309,7 @@ class svn_wc_entry_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_wc_entry_t, name)
     def __repr__(self):
-        return "<C svn_wc_entry_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_wc_entry_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["name"] = _wc.svn_wc_entry_t_name_set
     __swig_getmethods__["name"] = _wc.svn_wc_entry_t_name_get
     if _newclass:name = property(_wc.svn_wc_entry_t_name_get, _wc.svn_wc_entry_t_name_set)
@@ -256,6 +379,18 @@ class svn_wc_entry_t(_object):
     __swig_setmethods__["cmt_author"] = _wc.svn_wc_entry_t_cmt_author_set
     __swig_getmethods__["cmt_author"] = _wc.svn_wc_entry_t_cmt_author_get
     if _newclass:cmt_author = property(_wc.svn_wc_entry_t_cmt_author_get, _wc.svn_wc_entry_t_cmt_author_set)
+    __swig_setmethods__["lock_token"] = _wc.svn_wc_entry_t_lock_token_set
+    __swig_getmethods__["lock_token"] = _wc.svn_wc_entry_t_lock_token_get
+    if _newclass:lock_token = property(_wc.svn_wc_entry_t_lock_token_get, _wc.svn_wc_entry_t_lock_token_set)
+    __swig_setmethods__["lock_owner"] = _wc.svn_wc_entry_t_lock_owner_set
+    __swig_getmethods__["lock_owner"] = _wc.svn_wc_entry_t_lock_owner_get
+    if _newclass:lock_owner = property(_wc.svn_wc_entry_t_lock_owner_get, _wc.svn_wc_entry_t_lock_owner_set)
+    __swig_setmethods__["lock_comment"] = _wc.svn_wc_entry_t_lock_comment_set
+    __swig_getmethods__["lock_comment"] = _wc.svn_wc_entry_t_lock_comment_get
+    if _newclass:lock_comment = property(_wc.svn_wc_entry_t_lock_comment_get, _wc.svn_wc_entry_t_lock_comment_set)
+    __swig_setmethods__["lock_creation_date"] = _wc.svn_wc_entry_t_lock_creation_date_set
+    __swig_getmethods__["lock_creation_date"] = _wc.svn_wc_entry_t_lock_creation_date_get
+    if _newclass:lock_creation_date = property(_wc.svn_wc_entry_t_lock_creation_date_get, _wc.svn_wc_entry_t_lock_creation_date_set)
     def __init__(self, *args):
         _swig_setattr(self, svn_wc_entry_t, 'this', _wc.new_svn_wc_entry_t(*args))
         _swig_setattr(self, svn_wc_entry_t, 'thisown', 1)
@@ -264,6 +399,7 @@ class svn_wc_entry_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_wc_entry_tPtr(svn_wc_entry_t):
     def __init__(self, this):
         _swig_setattr(self, svn_wc_entry_t, 'this', this)
@@ -288,7 +424,7 @@ class svn_wc_entry_callbacks_t(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_wc_entry_callbacks_t, name)
     def __repr__(self):
-        return "<C svn_wc_entry_callbacks_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_wc_entry_callbacks_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["found_entry"] = _wc.svn_wc_entry_callbacks_t_found_entry_set
     __swig_getmethods__["found_entry"] = _wc.svn_wc_entry_callbacks_t_found_entry_get
     if _newclass:found_entry = property(_wc.svn_wc_entry_callbacks_t_found_entry_get, _wc.svn_wc_entry_callbacks_t_found_entry_set)
@@ -300,6 +436,7 @@ class svn_wc_entry_callbacks_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_wc_entry_callbacks_tPtr(svn_wc_entry_callbacks_t):
     def __init__(self, this):
         _swig_setattr(self, svn_wc_entry_callbacks_t, 'this', this)
@@ -308,6 +445,8 @@ class svn_wc_entry_callbacks_tPtr(svn_wc_entry_callbacks_t):
 _wc.svn_wc_entry_callbacks_t_swigregister(svn_wc_entry_callbacks_tPtr)
 
 
+svn_wc_walk_entries2 = _wc.svn_wc_walk_entries2
+
 svn_wc_walk_entries = _wc.svn_wc_walk_entries
 
 svn_wc_mark_missing_deleted = _wc.svn_wc_mark_missing_deleted
@@ -327,13 +466,63 @@ svn_wc_status_ignored = _wc.svn_wc_status_ignored
 svn_wc_status_obstructed = _wc.svn_wc_status_obstructed
 svn_wc_status_external = _wc.svn_wc_status_external
 svn_wc_status_incomplete = _wc.svn_wc_status_incomplete
+class svn_wc_status2_t(_object):
+    __swig_setmethods__ = {}
+    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_wc_status2_t, name, value)
+    __swig_getmethods__ = {}
+    __getattr__ = lambda self, name: _swig_getattr(self, svn_wc_status2_t, name)
+    def __repr__(self):
+        return "<%s.%s; proxy of C svn_wc_status2_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
+    __swig_setmethods__["entry"] = _wc.svn_wc_status2_t_entry_set
+    __swig_getmethods__["entry"] = _wc.svn_wc_status2_t_entry_get
+    if _newclass:entry = property(_wc.svn_wc_status2_t_entry_get, _wc.svn_wc_status2_t_entry_set)
+    __swig_setmethods__["text_status"] = _wc.svn_wc_status2_t_text_status_set
+    __swig_getmethods__["text_status"] = _wc.svn_wc_status2_t_text_status_get
+    if _newclass:text_status = property(_wc.svn_wc_status2_t_text_status_get, _wc.svn_wc_status2_t_text_status_set)
+    __swig_setmethods__["prop_status"] = _wc.svn_wc_status2_t_prop_status_set
+    __swig_getmethods__["prop_status"] = _wc.svn_wc_status2_t_prop_status_get
+    if _newclass:prop_status = property(_wc.svn_wc_status2_t_prop_status_get, _wc.svn_wc_status2_t_prop_status_set)
+    __swig_setmethods__["locked"] = _wc.svn_wc_status2_t_locked_set
+    __swig_getmethods__["locked"] = _wc.svn_wc_status2_t_locked_get
+    if _newclass:locked = property(_wc.svn_wc_status2_t_locked_get, _wc.svn_wc_status2_t_locked_set)
+    __swig_setmethods__["copied"] = _wc.svn_wc_status2_t_copied_set
+    __swig_getmethods__["copied"] = _wc.svn_wc_status2_t_copied_get
+    if _newclass:copied = property(_wc.svn_wc_status2_t_copied_get, _wc.svn_wc_status2_t_copied_set)
+    __swig_setmethods__["switched"] = _wc.svn_wc_status2_t_switched_set
+    __swig_getmethods__["switched"] = _wc.svn_wc_status2_t_switched_get
+    if _newclass:switched = property(_wc.svn_wc_status2_t_switched_get, _wc.svn_wc_status2_t_switched_set)
+    __swig_setmethods__["repos_text_status"] = _wc.svn_wc_status2_t_repos_text_status_set
+    __swig_getmethods__["repos_text_status"] = _wc.svn_wc_status2_t_repos_text_status_get
+    if _newclass:repos_text_status = property(_wc.svn_wc_status2_t_repos_text_status_get, _wc.svn_wc_status2_t_repos_text_status_set)
+    __swig_setmethods__["repos_prop_status"] = _wc.svn_wc_status2_t_repos_prop_status_set
+    __swig_getmethods__["repos_prop_status"] = _wc.svn_wc_status2_t_repos_prop_status_get
+    if _newclass:repos_prop_status = property(_wc.svn_wc_status2_t_repos_prop_status_get, _wc.svn_wc_status2_t_repos_prop_status_set)
+    __swig_setmethods__["repos_lock"] = _wc.svn_wc_status2_t_repos_lock_set
+    __swig_getmethods__["repos_lock"] = _wc.svn_wc_status2_t_repos_lock_get
+    if _newclass:repos_lock = property(_wc.svn_wc_status2_t_repos_lock_get, _wc.svn_wc_status2_t_repos_lock_set)
+    def __init__(self, *args):
+        _swig_setattr(self, svn_wc_status2_t, 'this', _wc.new_svn_wc_status2_t(*args))
+        _swig_setattr(self, svn_wc_status2_t, 'thisown', 1)
+    def __del__(self, destroy=_wc.delete_svn_wc_status2_t):
+        try:
+            if self.thisown: destroy(self)
+        except: pass
+
+
+class svn_wc_status2_tPtr(svn_wc_status2_t):
+    def __init__(self, this):
+        _swig_setattr(self, svn_wc_status2_t, 'this', this)
+        if not hasattr(self,"thisown"): _swig_setattr(self, svn_wc_status2_t, 'thisown', 0)
+        _swig_setattr(self, svn_wc_status2_t,self.__class__,svn_wc_status2_t)
+_wc.svn_wc_status2_t_swigregister(svn_wc_status2_tPtr)
+
 class svn_wc_status_t(_object):
     __swig_setmethods__ = {}
     __setattr__ = lambda self, name, value: _swig_setattr(self, svn_wc_status_t, name, value)
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, svn_wc_status_t, name)
     def __repr__(self):
-        return "<C svn_wc_status_t instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C svn_wc_status_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["entry"] = _wc.svn_wc_status_t_entry_set
     __swig_getmethods__["entry"] = _wc.svn_wc_status_t_entry_get
     if _newclass:entry = property(_wc.svn_wc_status_t_entry_get, _wc.svn_wc_status_t_entry_set)
@@ -366,6 +555,7 @@ class svn_wc_status_t(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class svn_wc_status_tPtr(svn_wc_status_t):
     def __init__(self, this):
         _swig_setattr(self, svn_wc_status_t, 'this', this)
@@ -374,40 +564,66 @@ class svn_wc_status_tPtr(svn_wc_status_t):
 _wc.svn_wc_status_t_swigregister(svn_wc_status_tPtr)
 
 
+svn_wc_dup_status2 = _wc.svn_wc_dup_status2
+
 svn_wc_dup_status = _wc.svn_wc_dup_status
 
+svn_wc_status2 = _wc.svn_wc_status2
+
 svn_wc_status = _wc.svn_wc_status
 
+svn_wc_get_status_editor2 = _wc.svn_wc_get_status_editor2
+
 svn_wc_get_status_editor = _wc.svn_wc_get_status_editor
 
+svn_wc_status_set_repos_locks = _wc.svn_wc_status_set_repos_locks
+
+svn_wc_copy2 = _wc.svn_wc_copy2
+
 svn_wc_copy = _wc.svn_wc_copy
 
+svn_wc_delete2 = _wc.svn_wc_delete2
+
 svn_wc_delete = _wc.svn_wc_delete
 
+svn_wc_add2 = _wc.svn_wc_add2
+
 svn_wc_add = _wc.svn_wc_add
 
 svn_wc_add_repos_file = _wc.svn_wc_add_repos_file
 
 svn_wc_remove_from_revision_control = _wc.svn_wc_remove_from_revision_control
 
+svn_wc_resolved_conflict2 = _wc.svn_wc_resolved_conflict2
+
 svn_wc_resolved_conflict = _wc.svn_wc_resolved_conflict
 
+svn_wc_process_committed2 = _wc.svn_wc_process_committed2
+
 svn_wc_process_committed = _wc.svn_wc_process_committed
 
+svn_wc_crawl_revisions2 = _wc.svn_wc_crawl_revisions2
+
 svn_wc_crawl_revisions = _wc.svn_wc_crawl_revisions
 
 svn_wc_is_wc_root = _wc.svn_wc_is_wc_root
 
 svn_wc_get_actual_target = _wc.svn_wc_get_actual_target
 
+svn_wc_get_update_editor2 = _wc.svn_wc_get_update_editor2
+
 svn_wc_get_update_editor = _wc.svn_wc_get_update_editor
 
+svn_wc_get_switch_editor2 = _wc.svn_wc_get_switch_editor2
+
 svn_wc_get_switch_editor = _wc.svn_wc_get_switch_editor
 
 svn_wc_prop_list = _wc.svn_wc_prop_list
 
 svn_wc_prop_get = _wc.svn_wc_prop_get
 
+svn_wc_prop_set2 = _wc.svn_wc_prop_set2
+
 svn_wc_prop_set = _wc.svn_wc_prop_set
 
 svn_wc_is_normal_prop = _wc.svn_wc_is_normal_prop
@@ -416,10 +632,14 @@ svn_wc_is_wc_prop = _wc.svn_wc_is_wc_prop
 
 svn_wc_is_entry_prop = _wc.svn_wc_is_entry_prop
 
+svn_wc_get_diff_editor3 = _wc.svn_wc_get_diff_editor3
+
 svn_wc_get_diff_editor2 = _wc.svn_wc_get_diff_editor2
 
 svn_wc_get_diff_editor = _wc.svn_wc_get_diff_editor
 
+svn_wc_diff3 = _wc.svn_wc_diff3
+
 svn_wc_diff2 = _wc.svn_wc_diff2
 
 svn_wc_diff = _wc.svn_wc_diff
@@ -436,10 +656,14 @@ svn_wc_merge_prop_diffs = _wc.svn_wc_merge_prop_diffs
 
 svn_wc_get_pristine_copy_path = _wc.svn_wc_get_pristine_copy_path
 
+svn_wc_cleanup2 = _wc.svn_wc_cleanup2
+
 svn_wc_cleanup = _wc.svn_wc_cleanup
 
 svn_wc_relocate = _wc.svn_wc_relocate
 
+svn_wc_revert2 = _wc.svn_wc_revert2
+
 svn_wc_revert = _wc.svn_wc_revert
 
 svn_wc_create_tmp_file = _wc.svn_wc_create_tmp_file
@@ -452,3 +676,7 @@ svn_wc_transmit_prop_deltas = _wc.svn_wc_transmit_prop_deltas
 
 svn_wc_get_default_ignores = _wc.svn_wc_get_default_ignores
 
+svn_wc_add_lock = _wc.svn_wc_add_lock
+
+svn_wc_remove_lock = _wc.svn_wc_remove_lock
+
